:mod:`kwant.physics` -- Physics-related algorithms
==================================================

.. module:: kwant.physics

Leads
-----
.. autosummary::
   :toctree: generated/

   Bands
   modes
   selfenergy
   two_terminal_shotnoise
   PropagatingModes
   StabilizedModes

Symmetry
--------
.. autosummary::
   :toctree: generated/

   DiscreteSymmetry

Computation of magnetic field gauge
-----------------------------------

.. autosummary::
   :toctree: generated/
   :template: autosummary/functor.rst

   magnetic_gauge
